@@ -1,14 +1,16 @@
-from typing import Optional, Union
 from decimal import Decimal
+from typing import Optional
+from typing import Union
 
-from pytezos.rpc import ShellQuery
-from pytezos.crypto.key import Key
-from pytezos.operation.group import OperationGroup
-from pytezos.operation.content import ContentMixin
-from pytezos.contract.interface import ContractInterface
+from pytezos.context.mixin import ContextMixin  # type: ignore
 from pytezos.contract.call import ContractCall
-from pytezos.context.mixin import ContextMixin
+from pytezos.contract.interface import ContractInterface
+from pytezos.crypto.key import Key
 from pytezos.jupyter import get_class_docstring
+from pytezos.logging import logger
+from pytezos.operation.content import ContentMixin
+from pytezos.operation.group import OperationGroup
+from pytezos.rpc import ShellQuery
 
 
 class PyTezosClient(ContextMixin, ContentMixin):
@@ -119,3 +121,11 @@ class PyTezosClient(ContextMixin, ContentMixin):
         :returns: A copy of current object with changes applied
         """
         return PyTezosClient(context=self._spawn_context(shell=shell, key=key, mode=mode))
+
+    @property
+    def loglevel(self) -> int:
+        return logger.level
+
+    @loglevel.setter
+    def loglevel(self, value: Union[str, int]) -> None:
+        logger.setLevel(value)
