@@ -1,7 +1,8 @@
-from typing import List, Type
+from typing import List
+from typing import Type
 
+from pytezos.context.abstract import AbstractContext  # type: ignore
 from pytezos.michelson.micheline import Micheline
-from pytezos.context.abstract import AbstractContext
 
 
 class CodeSection(Micheline, prim='code', args_len=1):
@@ -11,7 +12,7 @@ class CodeSection(Micheline, prim='code', args_len=1):
         cls = Micheline.match(code_expr)
         if not issubclass(cls, CodeSection):
             cls = CodeSection.create_type(args=[cls])
-        return cls
+        return cls  # type: ignore
 
     @classmethod
     def execute(cls, stack, stdout: List[str], context: AbstractContext):
