@@ -1,11 +1,22 @@
-from copy import deepcopy, copy
-from typing import Generator, Optional, Tuple, List, Union, Type
+from copy import copy
+from copy import deepcopy
+from typing import Generator
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import Type
+from typing import Union
 
-from pytezos.michelson.types.base import MichelsonType, Undefined
-from pytezos.michelson.micheline import parse_micheline_literal, Micheline, MichelineLiteral, MichelineSequence
-from pytezos.context.abstract import AbstractContext
-from pytezos.michelson.types.map import MapType, EltLiteral
+from pytezos.context.abstract import AbstractContext  # type: ignore
 from pytezos.michelson.forge import forge_script_expr
+from pytezos.michelson.micheline import Micheline
+from pytezos.michelson.micheline import MichelineLiteral
+from pytezos.michelson.micheline import MichelineSequence
+from pytezos.michelson.micheline import parse_micheline_literal
+from pytezos.michelson.types.base import MichelsonType
+from pytezos.michelson.types.base import Undefined
+from pytezos.michelson.types.map import EltLiteral
+from pytezos.michelson.types.map import MapType
 
 
 def big_map_diff_to_lazy_diff(big_map_diff: List[dict]):
@@ -48,7 +59,7 @@ class BigMapType(MapType, prim='big_map', args_len=2):
     def __len__(self):
         return len(self.items) + len(self.removed_keys)
 
-    def __iter__(self) -> Generator[Tuple[MichelsonType, Optional[MichelsonType]], None, None]:
+    def __iter__(self) -> Generator[Tuple[MichelsonType, Optional[MichelsonType]], None, None]:  # type: ignore
         yield from iter(self.items)
         for key in self.removed_keys:
             yield key, None
@@ -63,7 +74,7 @@ class BigMapType(MapType, prim='big_map', args_len=2):
     @staticmethod
     def empty(key_type: Type[MichelsonType], val_type: Type[MichelsonType]) -> 'BigMapType':
         cls = BigMapType.create_type(args=[key_type, val_type])
-        return cls(items=[])
+        return cls(items=[])  # type: ignore
 
     @staticmethod
     def from_items(items: List[Tuple[MichelsonType, MichelsonType]]):
@@ -199,7 +210,7 @@ class BigMapType(MapType, prim='big_map', args_len=2):
             else:
                 return self.args[1].from_micheline_value(val_expr)
         else:
-            return val
+            return val  # type: ignore
 
     def update(self, key: MichelsonType, val: Optional[MichelsonType]) -> Tuple[Optional[MichelsonType], MichelsonType]:
         removed_keys = set(self.removed_keys)
@@ -216,8 +227,8 @@ class BigMapType(MapType, prim='big_map', args_len=2):
                 if key in removed_keys:
                     removed_keys.remove(key)
             else:  # do nothing
-                items = self.items
-        res = type(self)(items=items, ptr=self.ptr, removed_keys=list(removed_keys))
+                items = self.items  # type: ignore
+        res = type(self)(items=items, ptr=self.ptr, removed_keys=list(removed_keys))  # type: ignore
         res.context = self.context
         return prev_val, res
 
@@ -235,6 +246,6 @@ class BigMapType(MapType, prim='big_map', args_len=2):
     def __deepcopy__(self, memodict={}):
         return self.duplicate()
 
-    def __getitem__(self, key_obj) -> Optional[MichelsonType]:
+    def __getitem__(self, key_obj) -> Optional[MichelsonType]:  # type: ignore
         key = self.args[0].from_python_object(key_obj)
         return self.get(key, dup=False)
