@@ -1,18 +1,29 @@
 from pprint import pformat
-from typing import List, Optional
+from typing import Any
+from typing import Dict
+from typing import List
+from typing import Optional
 
+from pytezos.context.impl import ExecutionContext  # type: ignore
+from pytezos.context.mixin import ContextMixin  # type: ignore
+from pytezos.crypto.encoding import base58_encode
 from pytezos.crypto.key import blake2b_32
+from pytezos.jupyter import get_class_docstring
+from pytezos.michelson.forge import forge_base58
 from pytezos.operation.content import ContentMixin
+from pytezos.operation.fees import calculate_fee
+from pytezos.operation.fees import default_fee
+from pytezos.operation.fees import default_gas_limit
+from pytezos.operation.fees import default_storage_limit
 from pytezos.operation.forge import forge_operation_group
-from pytezos.operation.fees import calculate_fee, default_fee, default_gas_limit, default_storage_limit
 from pytezos.operation.result import OperationResult
 from pytezos.rpc.errors import RpcError
-from pytezos.crypto.encoding import base58_encode
-from pytezos.michelson.forge import forge_base58
-from pytezos.context.mixin import ContextMixin
-from pytezos.context.impl import ExecutionContext
-from pytezos.jupyter import get_class_docstring
 
+DEFAULT_GAS_RESERVE = 100
+DEFAULT_BURN_RESERVE = 100
+DEFAULT_BRANCH_OFFSET = 50
+
+# FIXME: Add explaination of these values
 validation_passes = {
     'endorsement': 0,
     'proposal': 1,
@@ -33,9 +44,16 @@ class OperationGroup(ContextMixin, ContentMixin):
     and also useful helpers for filling with precise fees, signing, forging, and injecting.
     """
 
-    def __init__(self, context: ExecutionContext,
-                 contents=None, protocol=None, chain_id=None, branch=None, signature=None):
-        super(OperationGroup, self).__init__(context=context)
+    def __init__(
+        self,
+        context: ExecutionContext,
+        contents: Optional[List[Dict[str, Any]]] = None,
+        protocol: Optional[str] = None,
+        chain_id: Optional[int] = None,
+        branch: Optional[str] = None,
+        signature: Optional[str] = None,
+    ):
+        super().__init__(context=context)
         self.contents = contents or []
         self.protocol = protocol
         self.chain_id = chain_id
@@ -44,7 +62,7 @@ class OperationGroup(ContextMixin, ContentMixin):
 
     def __repr__(self):
         res = [
-            super(OperationGroup, self).__repr__(),
+            super().__repr__(),
             '\nPayload',
             pformat(self.json_payload()),
             '\nHelpers',
@@ -96,7 +114,7 @@ class OperationGroup(ContextMixin, ContentMixin):
         :param branch_offset: select head~offset block as branch, where offset is in range (0, 60)
         :rtype: OperationGroup
         """
-        assert 0 < branch_offset < 60, f'branch offset has to be in range (0, 60)'
+        assert 0 < branch_offset < 60, 'branch offset has to be in range (0, 60)'
         chain_id = self.chain_id or self.context.get_chain_id()
         branch = self.branch or self.shell.blocks[-branch_offset].hash()
         protocol = self.protocol or self.shell.head.header()['protocol']
@@ -166,12 +184,27 @@ class OperationGroup(ContextMixin, ContentMixin):
 
         return local_data
 
-    def autofill(self, gas_reserve=100, counter: Optional[int] = None, branch_offset=50):
-        """ Fill the gaps and then simulate the operation in order to calculate fee, gas/storage limits.
+    def autofill(
+        self,
+        gas_reserve: int = DEFAULT_GAS_RESERVE,
+        burn_reserve: int = DEFAULT_BURN_RESERVE,
+        counter: Optional[int] = None,
+        branch_offset: int = DEFAULT_BRANCH_OFFSET,
+        fee: Optional[int] = None,
+        gas_limit: Optional[int] = None,
+        storage_limit: Optional[int] = None,
+    ) -> 'OperationGroup':
+        """Fill the gaps and then simulate the operation in order to calculate fee, gas/storage limits.
 
-        :param gas_reserve: Add a safe reserve for gas limit (default is 100)
+        :param gas_reserve: Add a safe reserve for dynamically calculated gas limit (default is 100).
+        :param burn_reserve: Add a safe reserve for dynamically calculated storage limit (default is 100).
         :param counter: Override counter value (for manual handling)
-        :param branch_offset: select head~offset block as branch, where offset is in range (0, 60)
+        :param branch_offset: Select head~offset block as branch, where offset is in range (0, 60)
+        :param fee: Explicitly set fee for operation. If not set fee will be calculated depeding on results of operation dry-run.
+        :param gas_limit: Explicitly set gas limit for operation. If not set gas limit will be calculated depeding on results of
+            operation dry-run.
+        :param storage_limit: Explicitly set storage limit for operation. If not set storage limit will be calculated depeding on
+            results of operation dry-run.
         :rtype: OperationGroup
         """
         opg = self.fill(counter=counter, branch_offset=branch_offset)
@@ -179,19 +212,35 @@ class OperationGroup(ContextMixin, ContentMixin):
         if not OperationResult.is_applied(opg_with_metadata):
             raise RpcError.from_errors(OperationResult.errors(opg_with_metadata))
 
-        extra_size = (32 + 64) // len(opg.contents) + 1  # size of serialized branch and signature)
+        extra_size = (32 + 64) // len(opg.contents) + 1  # size of serialized branch and signature
 
-        def fill_content(content):
-            if validation_passes[content['kind']] == 3:
-                consumed_gas = OperationResult.consumed_gas(content) + gas_reserve
-                paid_storage_size_diff = OperationResult.paid_storage_size_diff(content)
-                burned = OperationResult.burned(content)
-                fee = calculate_fee(content, consumed_gas, extra_size)
-                content.update(
-                    gas_limit=str(consumed_gas + gas_reserve),
-                    storage_limit=str(paid_storage_size_diff + burned),
-                    fee=str(fee)
-                )
+        def fill_content(content: Dict[str, Any]) -> Optional[Dict[str, Any]]:
+            nonlocal fee
+            nonlocal gas_limit
+            nonlocal storage_limit
+
+            if validation_passes[content['kind']] != 3:
+                return None
+
+            if fee is None or gas_limit is None:
+                _consumed_gas = OperationResult.consumed_gas(content) + gas_reserve
+
+                if fee is None:
+                    fee = calculate_fee(content, _consumed_gas, extra_size)
+
+                if gas_limit is None:
+                    gas_limit = _consumed_gas + gas_reserve
+
+            if storage_limit is None:
+                _paid_storage_size_diff = OperationResult.paid_storage_size_diff(content)
+                _burned = OperationResult.burned(content)
+                storage_limit = _paid_storage_size_diff + _burned + burn_reserve
+
+            content.update(
+                gas_limit=str(gas_limit),
+                storage_limit=str(storage_limit),
+                fee=str(fee),
+            )
 
             content.pop('metadata')
             return content
@@ -261,20 +310,20 @@ class OperationGroup(ContextMixin, ContentMixin):
                 'hash': opg_hash,
                 **self.json_payload()
             }
-        else:
-            for i in range(num_blocks_wait):
-                self.shell.wait_next_block(time_between_blocks=time_between_blocks)
-                try:
-                    pending_opg = self.shell.mempool.pending_operations[opg_hash]
-                    if not OperationResult.is_applied(pending_opg):
-                        raise RpcError.from_errors(OperationResult.errors(pending_opg))
-                    print(f'Still in mempool: {opg_hash}')
-                except StopIteration:
-                    res = self.shell.blocks[-(i + 1):].find_operation(opg_hash)
-                    if check_result:
-                        if not OperationResult.is_applied(res):
-                            raise RpcError.from_errors(OperationResult.errors(res))
-                    return res
+
+        for i in range(num_blocks_wait):
+            self.shell.wait_next_block(time_between_blocks=time_between_blocks)
+            try:
+                pending_opg = self.shell.mempool.pending_operations[opg_hash]
+                if not OperationResult.is_applied(pending_opg):
+                    raise RpcError.from_errors(OperationResult.errors(pending_opg))
+                print(f'Still in mempool: {opg_hash}')
+            except StopIteration as exc:
+                res = self.shell.blocks[-(i + 1):].find_operation(opg_hash)
+                if check_result:
+                    if not OperationResult.is_applied(res):
+                        raise RpcError.from_errors(OperationResult.errors(res)) from exc
+                return res
 
         raise TimeoutError(opg_hash)
 
