@@ -1,8 +1,10 @@
 from os.path import dirname
 
-from pytezos.rpc.node import RpcNode
+from pytezos.jupyter import InlineDocstring
+from pytezos.jupyter import get_attr_docstring
+from pytezos.jupyter import get_class_docstring
 from pytezos.rpc.docs import rpc_docs
-from pytezos.jupyter import get_attr_docstring, get_class_docstring, InlineDocstring
+from pytezos.rpc.node import RpcNode
 
 
 def format_docstring(class_type, query_path):
@@ -55,11 +57,11 @@ def format_docstring(class_type, query_path):
 
 
 class RpcQuery(metaclass=InlineDocstring):
-    __extensions__ = dict()
+    __extensions__ = dict()  # type: ignore
 
     @classmethod
     def __init_subclass__(cls, path: str = '', **kwargs):
-        super().__init_subclass__(**kwargs)
+        super().__init_subclass__(**kwargs)  # type: ignore
         if isinstance(path, list):
             for sub_path in path:
                 cls.__extensions__[sub_path] = cls
